sequencetools.partition_sequence_once_by_weights_at_most_with_overhang
======================================================================

.. autofunction:: abjad.tools.sequencetools.partition_sequence_once_by_weights_at_most_with_overhang
